package ParkNPark.common;

/**
 * Contains a single log entry
 */
public class LogEntry
{
	/** Time that method call began */
	protected long probeIn;
	
	/** Time that method call completed */
	protected long probeOut;
	
	/** Method name */
	protected String probeMethod;
	
	/** Client name */
	protected String probeSource;
	
	/** Whether or not this log entry is finished */
	protected boolean logEntryFinished = false;

	/**
	 * Sets the starting time of the method call
	 * @param probeIn The method call starting time to use
	 */
	public void setProbeIn(long probeIn) {
		this.probeIn = probeIn;
	}

	/**
	 * Sets the name of the method being probed
	 * @param probeMethod The name of the method being probed
	 */
	public void setProbeMethod(String probeMethod) {
		this.probeMethod = probeMethod;
	}

	/**
	 * Sets the completed time of the method call
	 * @param probeOut The completed time of the method call
	 */
	public void setProbeOut(long probeOut) {
		this.probeOut = probeOut;
	}

	/**
	 * Sets the client name of the method call
	 * @param probeSource The client name of the method call
	 */
	public void setProbeSource(String probeSource) {
		this.probeSource = probeSource;
	}

	/**
	 * Returns the starting time of this method call
	 * @return The starting time of this method call
	 */
	public long getProbeIn() {
		return probeIn;
	}

	/**
	 * Returns the name of the method
	 * @return The name of the method
	 */
	public String getProbeMethod() {
		return probeMethod;
	}

	/**
	 * Returns the ending time of this method call
	 * @return The ending time of this method call
	 */
	public long getProbeOut() {
		return probeOut;
	}

	/**
	 * Returns the client name of the method call
	 * @return The client name of the method call
	 */
	public String getProbeSource() {
		return probeSource;
	}
	
	/**
	 * Returns true if this log entry is finished or false if it
	 * is not
	 * @return True if this log entry is finished or false if it
	 * is not
	 */
	public synchronized boolean isLogEntryFinished() {
		return logEntryFinished;
	}
	
	/**
	 * Marks this LogEntry as finished, which means that it is ready
	 * to be written to the log files
	 */
	public synchronized void markLogEntryAsFinished() {
		logEntryFinished = true;
	}
}
