package ParkNPark.tests;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Runs all 48 test configurations
 */
public class RunAll implements Runnable
{
	/** The project root folder */
	protected String projectRoot;

	/**
	 * Runs the entire test suite
	 * @param args Not used
	 */
	public static void main(String[] args)
	{
		// Get our project root from the current working folder
		File projectRoot = new File(System.getProperty("user.dir", ""));
		if (!projectRoot.getName().equals("tests")) {
			System.err.println("Current working folder is not \"tests\"; cannot guarantee directory structure; exiting");
			System.exit(1);
			return;
		}

		// Create our new test and run it
		(new RunAll(projectRoot.getParentFile().getAbsolutePath())).run();
	}
	
	/**
	 * Creates a new test suite runner for the given project root path
	 * @param projectRoot The root of the project to use in this test
	 * suite run
	 */
	public RunAll(String projectRoot) {
		this.projectRoot = projectRoot;
	}
	
	/**
	 * Runs the entire test suite
	 */
	public void run() {
		List<Integer> numClientsList = new ArrayList<Integer>(4);
		List<Integer> interRequestTimeList = new ArrayList<Integer>(3);
		List<Integer> replySizeList = new ArrayList<Integer>(4);
		
		// Build the number of clients list
		numClientsList.add(new Integer(1));
		numClientsList.add(new Integer(4));
		numClientsList.add(new Integer(7));
		numClientsList.add(new Integer(10));

		// Build the inter-request time list
		interRequestTimeList.add(new Integer(0));
		interRequestTimeList.add(new Integer(20));
		interRequestTimeList.add(new Integer(40));
		
		// Build the reply size list
		replySizeList.add(new Integer(0));
		replySizeList.add(new Integer(256));
		replySizeList.add(new Integer(512));
		replySizeList.add(new Integer(1024));
		
		// Run our test suite
		try {
			for (Integer numClients : numClientsList) {
				for (Integer interRequestTime : interRequestTimeList) {
					for (Integer replySize : replySizeList) {
						(new RunOne(projectRoot, numClients.intValue(), interRequestTime.intValue(), replySize.intValue())).run();
						System.out.println();
					}
				}
			}
		} catch (IOException e) {
			System.err.println(e.getMessage());
			System.exit(1);
			return;
		}
		
		// We are finished :-)!
		System.out.println("Test suite complete");
    }
}
